@@ -4,10 +4,7 @@ from woodwork.column_schema import ColumnSchema
 from woodwork.logical_types import Datetime, Double
 
 from featuretools.primitives.base.transform_primitive_base import TransformPrimitive
-from featuretools.primitives.rolling_primitive_utils import (
-    apply_roll_with_offset_gap,
-    roll_series_with_gap,
-)
+from featuretools.primitives.rolling_primitive_utils import apply_rolling_agg_to_series
 from featuretools.utils import calculate_trend
 
 
@@ -24,16 +21,16 @@ class RollingMax(TransformPrimitive):
 
     Args:
         window_length (int, string, optional): Specifies the amount of data included in each window.
-            If an integer is provided, will correspond to a number of rows. For data with a uniform sampling frequency,
+            If an integer is provided, it will correspond to a number of rows. For data with a uniform sampling frequency,
             for example of one day, the window_length will correspond to a period of time, in this case,
             7 days for a window_length of 7.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time that each window should span.
-            The list of available offset aliases, can be found at
+            The list of available offset aliases can be found at
             https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases.
             Defaults to 3.
         gap (int, string, optional): Specifies a gap backwards from each instance before the
-            window of usable data begins. If an integer is provided, will correspond to a number of rows.
+            window of usable data begins. If an integer is provided, it will correspond to a number of rows.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time between a target instance and the beginning of its window.
             Defaults to 0, which will include the target instance in the window.
@@ -46,7 +43,7 @@ class RollingMax(TransformPrimitive):
     Note:
         Only offset aliases with fixed frequencies can be used when defining gap and window_length.
         This means that aliases such as `M` or `W` cannot be used, as they can indicate different
-        numbers of days. ('M', because different months are different numbers of days;
+        numbers of days. ('M', because different months have different numbers of days;
         'W' because week will indicate a certain day of the week, like W-Wed, so that will
         indicate a different number of days depending on the anchoring date.)
 
@@ -103,21 +100,14 @@ class RollingMax(TransformPrimitive):
     def get_function(self):
         def rolling_max(datetime, numeric):
             x = pd.Series(numeric.values, index=datetime.values)
-            rolled_series = roll_series_with_gap(
+            return apply_rolling_agg_to_series(
                 x,
+                lambda series: series.max(),
                 self.window_length,
-                gap=self.gap,
-                min_periods=self.min_periods,
+                self.gap,
+                self.min_periods,
             )
 
-            if isinstance(self.gap, str):
-                additional_args = (self.gap, max, self.min_periods)
-                return rolled_series.apply(
-                    apply_roll_with_offset_gap,
-                    args=additional_args,
-                ).values
-            return rolled_series.max().values
-
         return rolling_max
 
 
@@ -133,16 +123,16 @@ class RollingMin(TransformPrimitive):
 
     Args:
         window_length (int, string, optional): Specifies the amount of data included in each window.
-            If an integer is provided, will correspond to a number of rows. For data with a uniform sampling frequency,
+            If an integer is provided, it will correspond to a number of rows. For data with a uniform sampling frequency,
             for example of one day, the window_length will correspond to a period of time, in this case,
             7 days for a window_length of 7.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time that each window should span.
-            The list of available offset aliases, can be found at
+            The list of available offset aliases can be found at
             https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases.
             Defaults to 3.
         gap (int, string, optional): Specifies a gap backwards from each instance before the
-            window of usable data begins. If an integer is provided, will correspond to a number of rows.
+            window of usable data begins. If an integer is provided, it will correspond to a number of rows.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time between a target instance and the beginning of its window.
             Defaults to 0, which will include the target instance in the window.
@@ -155,7 +145,7 @@ class RollingMin(TransformPrimitive):
     Note:
         Only offset aliases with fixed frequencies can be used when defining gap and window_length.
         This means that aliases such as `M` or `W` cannot be used, as they can indicate different
-        numbers of days. ('M', because different months are different numbers of days;
+        numbers of days. ('M', because different months have different numbers of days;
         'W' because week will indicate a certain day of the week, like W-Wed, so that will
         indicate a different number of days depending on the anchoring date.)
 
@@ -212,21 +202,14 @@ class RollingMin(TransformPrimitive):
     def get_function(self):
         def rolling_min(datetime, numeric):
             x = pd.Series(numeric.values, index=datetime.values)
-            rolled_series = roll_series_with_gap(
+            return apply_rolling_agg_to_series(
                 x,
+                lambda series: series.min(),
                 self.window_length,
-                gap=self.gap,
-                min_periods=self.min_periods,
+                self.gap,
+                self.min_periods,
             )
 
-            if isinstance(self.gap, str):
-                additional_args = (self.gap, min, self.min_periods)
-                return rolled_series.apply(
-                    apply_roll_with_offset_gap,
-                    args=additional_args,
-                ).values
-            return rolled_series.min().values
-
         return rolling_min
 
 
@@ -243,16 +226,16 @@ class RollingMean(TransformPrimitive):
 
     Args:
         window_length (int, string, optional): Specifies the amount of data included in each window.
-            If an integer is provided, will correspond to a number of rows. For data with a uniform sampling frequency,
+            If an integer is provided, it will correspond to a number of rows. For data with a uniform sampling frequency,
             for example of one day, the window_length will correspond to a period of time, in this case,
             7 days for a window_length of 7.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time that each window should span.
-            The list of available offset aliases, can be found at
+            The list of available offset aliases can be found at
             https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases.
             Defaults to 3.
         gap (int, string, optional): Specifies a gap backwards from each instance before the
-            window of usable data begins. If an integer is provided, will correspond to a number of rows.
+            window of usable data begins. If an integer is provided, it will correspond to a number of rows.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time between a target instance and the beginning of its window.
             Defaults to 0, which will include the target instance in the window.
@@ -265,7 +248,7 @@ class RollingMean(TransformPrimitive):
     Note:
         Only offset aliases with fixed frequencies can be used when defining gap and window_length.
         This means that aliases such as `M` or `W` cannot be used, as they can indicate different
-        numbers of days. ('M', because different months are different numbers of days;
+        numbers of days. ('M', because different months have different numbers of days;
         'W' because week will indicate a certain day of the week, like W-Wed, so that will
         indicate a different number of days depending on the anchoring date.)
 
@@ -314,20 +297,14 @@ class RollingMean(TransformPrimitive):
     def get_function(self):
         def rolling_mean(datetime, numeric):
             x = pd.Series(numeric.values, index=datetime.values)
-            rolled_series = roll_series_with_gap(
+            return apply_rolling_agg_to_series(
                 x,
+                np.mean,
                 self.window_length,
-                gap=self.gap,
-                min_periods=self.min_periods,
+                self.gap,
+                self.min_periods,
             )
 
-            if isinstance(self.gap, str):
-                additional_args = (self.gap, np.mean, self.min_periods)
-                return rolled_series.apply(
-                    apply_roll_with_offset_gap, args=additional_args
-                ).values
-            return rolled_series.mean().values
-
         return rolling_mean
 
 
@@ -343,16 +320,16 @@ class RollingSTD(TransformPrimitive):
 
     Args:
         window_length (int, string, optional): Specifies the amount of data included in each window.
-            If an integer is provided, will correspond to a number of rows. For data with a uniform sampling frequency,
+            If an integer is provided, it will correspond to a number of rows. For data with a uniform sampling frequency,
             for example of one day, the window_length will correspond to a period of time, in this case,
             7 days for a window_length of 7.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time that each window should span.
-            The list of available offset aliases, can be found at
+            The list of available offset aliases can be found at
             https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases.
             Defaults to 3.
         gap (int, string, optional): Specifies a gap backwards from each instance before the
-            window of usable data begins. If an integer is provided, will correspond to a number of rows.
+            window of usable data begins. If an integer is provided, it will correspond to a number of rows.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time between a target instance and the beginning of its window.
             Defaults to 0, which will include the target instance in the window.
@@ -365,7 +342,7 @@ class RollingSTD(TransformPrimitive):
     Note:
         Only offset aliases with fixed frequencies can be used when defining gap and window_length.
         This means that aliases such as `M` or `W` cannot be used, as they can indicate different
-        numbers of days. ('M', because different months are different numbers of days;
+        numbers of days. ('M', because different months have different numbers of days;
         'W' because week will indicate a certain day of the week, like W-Wed, so that will
         indicate a different number of days depending on the anchoring date.)
 
@@ -421,26 +398,14 @@ class RollingSTD(TransformPrimitive):
     def get_function(self):
         def rolling_std(datetime, numeric):
             x = pd.Series(numeric.values, index=datetime.values)
-            rolled_series = roll_series_with_gap(
+            return apply_rolling_agg_to_series(
                 x,
+                lambda series: series.std(),
                 self.window_length,
-                gap=self.gap,
-                min_periods=self.min_periods,
+                self.gap,
+                self.min_periods,
             )
 
-            if isinstance(self.gap, str):
-
-                def _pandas_std(series):
-                    return series.std()
-
-                additional_args = (self.gap, _pandas_std, self.min_periods)
-
-                return rolled_series.apply(
-                    apply_roll_with_offset_gap,
-                    args=additional_args,
-                ).values
-            return rolled_series.std().values
-
         return rolling_std
 
 
@@ -457,16 +422,16 @@ class RollingTrend(TransformPrimitive):
 
      Args:
         window_length (int, string, optional): Specifies the amount of data included in each window.
-            If an integer is provided, will correspond to a number of rows. For data with a uniform sampling frequency,
+            If an integer is provided, it will correspond to a number of rows. For data with a uniform sampling frequency,
             for example of one day, the window_length will correspond to a period of time, in this case,
             7 days for a window_length of 7.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time that each window should span.
-            The list of available offset aliases, can be found at
+            The list of available offset aliases can be found at
             https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases.
             Defaults to 3.
         gap (int, string, optional): Specifies a gap backwards from each instance before the
-            window of usable data begins. If an integer is provided, will correspond to a number of rows.
+            window of usable data begins. If an integer is provided, it will correspond to a number of rows.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time between a target instance and the beginning of its window.
             Defaults to 0, which will include the target instance in the window.
@@ -517,16 +482,13 @@ class RollingTrend(TransformPrimitive):
     def get_function(self):
         def rolling_trend(datetime, numeric):
             x = pd.Series(numeric.values, index=datetime.values)
-            rolled_series = roll_series_with_gap(
-                x, self.window_length, gap=self.gap, min_periods=self.min_periods
+            return apply_rolling_agg_to_series(
+                x,
+                calculate_trend,
+                self.window_length,
+                self.gap,
+                self.min_periods,
             )
-            if isinstance(self.gap, str):
-                additional_args = (self.gap, calculate_trend, self.min_periods)
-                return rolled_series.apply(
-                    apply_roll_with_offset_gap,
-                    args=additional_args,
-                ).values
-            return rolled_series.apply(calculate_trend).values
 
         return rolling_trend
 
@@ -543,16 +505,16 @@ class RollingCount(TransformPrimitive):
 
     Args:
         window_length (int, string, optional): Specifies the amount of data included in each window.
-            If an integer is provided, will correspond to a number of rows. For data with a uniform sampling frequency,
+            If an integer is provided, it will correspond to a number of rows. For data with a uniform sampling frequency,
             for example of one day, the window_length will correspond to a period of time, in this case,
             7 days for a window_length of 7.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time that each window should span.
-            The list of available offset aliases, can be found at
+            The list of available offset aliases can be found at
             https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases.
             Defaults to 3.
         gap (int, string, optional): Specifies a gap backwards from each instance before the
-            window of usable data begins. If an integer is provided, will correspond to a number of rows.
+            window of usable data begins. If an integer is provided, it will correspond to a number of rows.
             If a string is provided, it must be one of pandas' offset alias strings ('1D', '1H', etc),
             and it will indicate a length of time between a target instance and the beginning of its window.
             Defaults to 0, which will include the target instance in the window.
@@ -565,7 +527,7 @@ class RollingCount(TransformPrimitive):
     Note:
         Only offset aliases with fixed frequencies can be used when defining gap and h.
         This means that aliases such as `M` or `W` cannot be used, as they can indicate different
-        numbers of days. ('M', because different months are different numbers of days;
+        numbers of days. ('M', because different months have different numbers of days;
         'W' because week will indicate a certain day of the week, like W-Wed, so that will
         indicate a different number of days depending on the anchoring date.)
 
@@ -619,33 +581,13 @@ class RollingCount(TransformPrimitive):
     def get_function(self):
         def rolling_count(datetime):
             x = pd.Series(1, index=datetime)
-            rolled_series = roll_series_with_gap(
+            return apply_rolling_agg_to_series(
                 x,
+                lambda series: series.count(),
                 self.window_length,
-                gap=self.gap,
-                min_periods=self.min_periods,
+                self.gap,
+                self.min_periods,
+                ignore_window_nans=True,
             )
 
-            if isinstance(self.gap, str):
-                # Since apply_roll_with_offset_gap doesn't artificially add nans before rolling,
-                # it produces correct results
-                additional_args = (self.gap, len, self.min_periods)
-                return rolled_series.apply(
-                    apply_roll_with_offset_gap,
-                    args=additional_args,
-                ).values
-
-            rolling_count_series = rolled_series.count()
-
-            # The shift made to account for gap adds NaNs to the rolled series
-            # Those values get counted towards min_periods when they shouldn't.
-            # So we need to replace any of those partial values with NaNs
-            if not self.min_periods:
-                # when min periods is 0 or None it's treated the same as if it's 1
-                num_nans = self.gap
-            else:
-                num_nans = self.min_periods - 1 + self.gap
-            rolling_count_series.iloc[range(num_nans)] = np.nan
-            return rolling_count_series.values
-
         return rolling_count
