@@ -1,3 +1,5 @@
+import warnings
+
 import numpy as np
 import pandas as pd
 from woodwork.column_schema import ColumnSchema
@@ -623,6 +625,10 @@ class NumericLag(TransformPrimitive):
     def __init__(self, periods=1, fill_value=None):
         self.periods = periods
         self.fill_value = fill_value
+        warnings.warn(
+            "NumericLag is deprecated and will be removed in a future version. Please use the 'Lag' primitive instead.",
+            FutureWarning,
+        )
 
     def get_function(self):
         def lag(time_index, numeric):
@@ -630,3 +636,55 @@ class NumericLag(TransformPrimitive):
             return x.shift(periods=self.periods, fill_value=self.fill_value).values
 
         return lag
+
+
+class Lag(TransformPrimitive):
+    """Shifts an array of values by a specified number of periods.
+
+    Args:
+        periods (int): The number of periods by which to shift the input.
+            Default is 1. Periods correspond to rows.
+
+    Examples:
+        >>> lag = Lag()
+        >>> lag([1, 2, 3, 4, 5], pd.Series(pd.date_range(start="2020-01-01", periods=5, freq='D'))).tolist()
+        [nan, 1.0, 2.0, 3.0, 4.0]
+
+        You can specify the number of periods to shift the values
+
+        >>> lag_periods = Lag(periods=3)
+        >>> lag_periods(["hello", "world", "test", "foo", "bar"], pd.Series(pd.date_range(start="2020-01-01", periods=5, freq='D'))).tolist()
+        [nan, nan, nan, 'hello', 'world']
+    """
+
+    name = "lag"
+    input_types = [
+        [
+            ColumnSchema(semantic_tags={"category"}),
+            ColumnSchema(semantic_tags={"time_index"}),
+        ],
+        [
+            ColumnSchema(semantic_tags={"numeric"}),
+            ColumnSchema(semantic_tags={"time_index"}),
+        ],
+        [
+            ColumnSchema(logical_type=Boolean),
+            ColumnSchema(semantic_tags={"time_index"}),
+        ],
+        [
+            ColumnSchema(logical_type=BooleanNullable),
+            ColumnSchema(semantic_tags={"time_index"}),
+        ],
+    ]
+    return_type = None
+    uses_full_dataframe = True
+
+    def __init__(self, periods=1):
+        self.periods = periods
+
+    def get_function(self):
+        def lag(input_col, time_index):
+            x = pd.Series(input_col.values, index=time_index.values)
+            return x.shift(periods=self.periods, fill_value=None).values
+
+        return lag
