@@ -2,6 +2,7 @@ import pandas as pd
 import pytest
 
 from featuretools import calculate_feature_matrix, dfs, list_primitives
+from featuretools.feature_base.cache import feature_cache
 from featuretools.primitives import get_aggregation_primitives, get_transform_primitives
 from featuretools.utils.gen_utils import Library
 
@@ -17,6 +18,12 @@ UNSUPPORTED += [
 ]
 
 
+@pytest.fixture(autouse=True)
+def reset_dfs_cache():
+    feature_cache.enabled = False
+    feature_cache.clear_all()
+
+
 def test_transform(pd_es, dask_es):
     pytest.skip(
         "TODO: Dask issue with `series.eq`. Fix once Dask Issue #7957 is closed.",
