@@ -1,5 +1,6 @@
 from datetime import datetime
 
+import holidays
 import numpy as np
 import pandas as pd
 import pytest
@@ -36,7 +37,8 @@ def test_holiday_out_of_range():
             datetime(2020, 12, 31),
         ],
     )
-    answer = pd.Series([np.nan, 209, 148, np.nan])
+    days_to_boxing_day = -157 if float(holidays.__version__) >= 0.15 else 209
+    answer = pd.Series([np.nan, days_to_boxing_day, 148, np.nan])
     pd.testing.assert_series_equal(date_to_holiday(array), answer, check_names=False)
 
 
